import { useAppDispatch, useAuthCache } from '../store';
import { authenticated, changeRoom, UserAuthenticationHeader } from '../store/authSlice';
import { addInfo, addError } from '../store/configSlice';

const domain = import.meta.env.BACKEND_URL;
const userURI = import.meta.env.BACKEND_USER;

export const fetchSettings: RequestInit = {
  method: 'GET',
  credentials: 'include',
  redirect: 'follow',
};

export const useAuthentication = () => {
  const dispatch = useAppDispatch();
  const auth = useAuthCache();

  const handleError = (err: any) => {
    console.error(err);
    dispatch(addError('Failed to copy: ' + (err.message || 'Unknown error occurred')));
  };

  const login = () => {
    fetch(`${domain}${userURI}/headers`, fetchSettings)
      .then((res) =>
        res
          .json()
          .then((res: UserAuthenticationHeader) => {
            dispatch(
              authenticated({
                username: res.username,
                userID: res.userID,
                sessionID: res.sessionID,
                jwt: res.jwt,
                authenticated: true,
                roomID: res.roomID,
              }),
            );
          })
          .catch(handleError),
      )
      .catch(handleError);
  };

  const copyToClipboard = async (text: string) => {
    try {
      await navigator.clipboard.writeText(text);
      return true;
    } catch (err) {
      console.error('Failed to copy:', err);
      return false;
    }
  };

  const newShareRoom = async () => {
    try {
      // TODO: Implement share room functionality when backend is ready
      // fetch(`${domain}${userURI}/share`, { ...fetchSettings, method: 'POST' })
      //   .then((res) =>
      //     res
      //       .json()
      //       .then((res: { Roomid: string; Sessionid: string }) => {
      //         dispatch(changeRoom(res.Roomid));
      //       })
      //       .catch(handleError),
      //   )
      //   .catch(handleError);

      const shareUrl = window.location.href;
      const copied = await copyToClipboard(shareUrl);
      
      if (copied) {
        dispatch(addInfo('Link copied to clipboard!'));
      } else {
        throw new Error('Failed to copy to clipboard');
      }
    } catch (error: any) {
      handleError(error);
    }
  };

  return { login, newShareRoom };
};